#
# spec file for package latexila
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           latexila
Version:        3.26.1
Release:        lp151.2.2
Summary:        Integrated LaTeX Environment for the GNOME desktop
License:        GPL-3.0+
Group:          Productivity/Publishing/TeX/Frontends
Url:            https://projects.gnome.org/latexila/
Source0:        https://download.gnome.org/sources/latexila/3.26/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gnome-desktop
BuildRequires:  gsettings-desktop-schemas-devel
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.34
BuildRequires:  pkgconfig(gee-0.8) >= 0.10
BuildRequires:  pkgconfig(gio-2.0) >= 2.50
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gspell-1) >= 1.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtksourceview-3.0) >= 3.24
BuildRequires:  pkgconfig(tepl-3) >= 3.0
BuildRequires:  pkgconfig(vapigen) >= 0.34
Requires:       gsettings-desktop-schemas
Requires:       texlive-latexmk-bin

%description
LaTeXila is an Integrated LaTeX Environment for GNOME. The main features are:
  * Configurable buttons to compile, convert and view a document in one click
  * LaTeX commands auto-completion
  * Symbol tables (Greek letters, arrows, ...)
  * File browser integrated
  * Template managing
  * Menus with the most commonly used LaTeX commands
  * Easy projects management

%prep
%setup -q
%if !0%{?is_opensuse}
translation-update-upstream
%endif

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file org.gnome.%{name} WordProcessor
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING README NEWS HACKING
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/*/
%{_datadir}/applications/*
%{_datadir}/dbus-1/services/org.gnome.latexila.service
%{_datadir}/glib-2.0/schemas/org.gnome.%{name}.gschema.xml
%{_datadir}/appdata/org.gnome.latexila.appdata.xml
%{_mandir}/man1/%{name}.1.*
%dir %{_datadir}/gtk-doc/html/latexila/
%{_datadir}/gtk-doc/html/latexila/*

%changelog
* Wed Nov  1 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Updated translations.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_* and
  %%icon_theme_cache_* post/postun/requires macros: functionality
  now covered by file triggers.
- Conditionalize use of translation-update-upstream: sle-only
  requirement.
- Align with configure:
  + Drop gettext-tools BuildRequires.
  + Add gtk-doc and pkgconfig(glib-2.0) BuildRequires.
* Sat Oct 28 2017 jengelh@inai.de
- Use standardized %%configure call.
* Thu Sep 14 2017 fezhang@suse.com
- Drop SLE12 / Leap42 conditional, %%{_datadir}/appdata is now owned
  by the filesystem package.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Internal code refactoring, use more Tepl features.
  + latexmk post-processor: fix bug with LaTeX errors and warnings
    not detected with new versions of latexmk.
  + Small improvement: make the tab label tooltip clearer:
    "Main file" -> "Project main file".
  + Small bug fixes:
  - Search: replace all button: center content vertically.
  - LaTeX and Math menus: grab focus to active text view after
    inserting text.
  + Updated translations.
* Wed Aug 23 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + The Gtef library has been renamed to Tepl, adapt the code
    accordingly.
  + Use more Tepl features.
  + Code maintenance to not use a deprecated GTK+ function.
  + Updated translations.
- Replace pkgconfig(gtef-2) BuildRequires with pkgconfig(tepl-3),
  following upstreams port.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + latexmk post-processor: fix bug with LaTeX errors and warnings
    not detected with new versions of latexmk.
  + Small bug fixes:
  - Search: replace all button: center content vertically.
  - LaTeX and Math menus: grab focus to active text view after
    inserting text.
* Sun Jun 25 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Fix a crash when moving a tab to a new window (regression in
    3.24).
* Sun Jun 11 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Create app menu only if the desktop prefers one, to avoid a
    double menubar on e.g. Xfce.
  + Other small code improvements.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Sun Mar 12 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Easier keyboard shortcuts for bold, italic and underline:
    <Control>B/I/U.
  + In the menus to open a recently used file, show a tooltip with
    the full path.
  + Document structure: fix bug to allow "TODO: ..." and
    "FIXME: ..." (with the colon).
  + Other small code improvements.
  + Fix minor issues found by Coverity.
  + Updated translations.
* Sat Jan 28 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Update code to not use deprecated GtkSourceView APIs.
  + Use the Gtef library; Some functionality has been moved from
    LaTeXila to Gtef.
  + Change menu item label "Search Forward" -> "Jump to PDF" to not
    confuse it with the normal search and replace feature. And
    adapt the docs accordingly.
  + Update the build system to use autoconf-archive macros instead
    of gnome-common.
  + Updated translations.
- Add pkgconfig(gtef-2) BuildRequires: new dependency.
* Sun Dec 18 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix Vala compilation error with newer valac compiler.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Fundraising.
  + Update AppData.
  + Updated translations.
* Fri Jul 29 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Bug fix: initialize correctly the build view settings (to hide
    warnings/badboxes).
  + Updated translations.
* Sun Mar 20 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Mon Mar 14 2016 zaitor@opensuse.org
- Update to version 3.19.5:
  + Adapt code for gspell API changes.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.4:
  + Close fundraiser.
  + Adapt code for gspell API changes.
  + AppData: add translation tag.
  + Updated translations.
* Wed Jan 27 2016 zaitor@opensuse.org
- Update to version 3.19.3:
  + Adapt code for gspell API changes.
  + Adapt code to support again loading and saving remote files.
  + Better gnome-shell integration: add an application menu and fix
    the "Open a New Window" right-click action.
  + Make LaTeXila D-Bus activatable.
  + Change "Unsaved Document" to "Untitled Document".
  + Other various small code improvements.
  + Updated translations.
* Sat Dec 19 2015 badshah400@gmail.com
- Update to version 3.19.2:
  + Adapt code for GspellLanguage API changes.
  + Adapt CSS to track GTK+ changes.
  + Rename latexila.deskop to org.gnome.latexila.desktop.
  + Rename AppData to org.gnome.latexila.appdata.xml.
  + Other various small improvements and bug fixes.
- Update file list to reflect change of file names:
  + Desktop menu entry got renamed to org.gnome.latexila.desktop.
  + Appdata file got renamed to org.gnome.latexila.appdata.xml.
- Changes from version 3.19.1:
  + Adapt code for GspellLanguageChooserDialog change.
* Sat Dec 19 2015 badshah400@gmail.com
- Update to version 3.18.2:
  + AppData: add kudos.
  + Fix a syntax error in desktop file keywords German
    translation.
  + Adapt code to support again remote files.
* Fri Nov 13 2015 badshah400@gmail.com
- Update to version 3.18.1:
  - Fix regressions from gtk+ changes during the 3.18 cycle.
  - Updated translations.
- Changes from version 3.18.0:
  - Use gspell instead of GtkSpell.
  - Add default spell checking settings in the preferences dialog.
  - Via the Tools menu, the spell checking settings can be changed
    and are stored on a file-by-file basis.
  - There is now a spell checker dialog window, to spell check an
    entire file word-by-word.
  - Ensure that the personal build tools and the templates are
    correctly saved.
  - Other various small improvements and bug fixes.
  - Translation updates.
- Update BuildRequires:
  + Add pkgconfig(gspell-1)
  + Add pkgconfig(gobject-introspection-1.0)
  + Add pkgconfig(vapigen)
  + Update required versions
  + Remove pkgconfig(gtkspell3-3.0).
- Remove runtime dependency on rubber (no longer used for
  latexila's build tools), add texlive-latexmk-bin instead.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Ensure that the personal build tools are correctly saved.
  + A few other small bug fixes.
  + Updated translations.
* Sat Aug 15 2015 badshah400@gmail.com
- For openSUSE:42, have package own the /usr/share/appdata dir;
  fixes build failure.
* Sun Apr 19 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix the build with -Werror=format-security.
  + Important bug fix when deleting several templates at once.
* Wed Mar 25 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Various small improvements.
  + Updated translations.
* Wed Mar 25 2015 zaitor@opensuse.org
- Update to version 3.14.4:
  + Show information about LaTeXila fundraiser.
  + Various bug fixes.
  + Updated translations.
* Wed Jan  7 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Adapt code for GtkSourceView 3.14.3.
  + Updated translations.
* Mon Nov  3 2014 badshah400@gmail.com
- Update to version 3.14.2:
  + Build: a file was missing in tarballs
  + Add keywords to latexila.desktop
  + Translation updates.
* Wed Oct  1 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + A few bug fixes and small improvements.
  + GTK+ 3.14 is required because LaTeXila overrides some CSS
    properties and assumes that GTK+ 3.14 is used.
- Drop conditional pkgconfig(gtkspell-3.0) and xz BuildRequires for
  older version of openSUSE, as latexila now has a hard BuildReq on
  pkgconfig(gtk+-3.0) >= 3.14.0.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Now LaTeXila follows the GNOME versions.
  + Better icons.
  + Upgrade to gee-0.8.
  + Other small improvements.
- Changes from version 3.12.1:
  + Fix regex in latex post-processor.
  + GLib 2.40 is required
  + Updated translations.
- Changes from version 3.12.0:
  + Refresh structure when saving.
  + Misc bugfixes and small improvements.
  + Updated translations.
- Changes from version 2.10.0:
  + Updated translations.
- Changes from version 2.9.0:
  + Search and replace: use the new API from GtkSourceView.
  + Use upstream GtkSpell (LaTeXila depends on GtkSpell now,
    instead of Enchant).
  + Improvements to the completion.
  + AppData file.
  + Updated translations.
- Drop obsolete pkgconfig(enchant) BuildRequires, no longer needed.
- Replace pkgconfig(gee-1.0) for pkgconfig(gee-0.8) BuildRequires,
  following upstream changes.
- Add pkgconfig(gio-2.0) BuildRequires: New dependency.
* Thu Sep 19 2013 badshah400@gmail.com
- Update to version 2.8.3:
  + Build tools: fix crash on unknown post processor
  + Updated Galician translations
- Drop latexila-fix-makefile.patch; properly fixed upstream
- Drop latexila-do-not-disable-deprecated-apis.patch; patch
  implemented upstream. Also drop autotool build requirements due
  to this patch.
* Thu Aug 29 2013 badshah400@gmail.com
- Fix source URL.
* Mon Aug 26 2013 badshah400@gmail.com
- Update to version 2.8.2:
  + Misc bugfixes
- Add latexila-do-not-disable-deprecated-apis.patch to enable
  usage of deprecated symbols in gtk3-3.9.10; this fixes build
  failures in Factory; patch taken from upstream git.
- Add latexila-fix-makefile.patch to fix trivial issue in a
  makefile which caused build errors.
* Tue May  7 2013 badshah400@gmail.com
- Update to version 2.8.1:
  + Bump required version of GLib to 2.36
  + Add Catalan and Greek translations
  + Translations updates
  + Misc bugfixes
- Drop patch
  latexila-replace-deprecated-gtk_widget_render_icon.patch;
  implemented upstream.
* Sun May  5 2013 badshah400@gmail.com
- Update to version 2.8.0:
  + Allow the menu bar to shrink below its minimum size
  + Load and save accelerator maps (it's now possible to edit the
    keyboard shortcuts)
  + Change the application icons
  + Add Ctrl+E shortcut for \emph{}
  + Improvements to the completion
  + Misc bugfixes
  + Translations updates
- Fix gtkspell buildrequires, Factory and above require gtkspell3
  instead of gtkspell now
- Now requires gtk+-3.0 >= 3.6.0 and gtksourceview >= 3.8.0 for
  building
- Add patch
  latexila-replace-deprecated-gtk_widget_render_icon.patch to
  replace deprecated gtk_widget_render_icon by
  gtk_widget_render_icon_pixbuf; fixes build failure due to
  "64bit portability issues".
* Thu Feb 28 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Thu Oct 25 2012 badshah400@gmail.com
- Update to version 2.6.1:
  + Autotools: required version of Vala is now optional
  + Comment selected lines: comment empty lines too
  + Misc bug fixes
- Changes from versions 2.6.0, 2.5.2, 2.5.3, 2.5.4:
  + See installed NEWS file for list of changes
- Modify spec file to adapt to (upstream) change of build from
  previously cmake based procedure to autotools based procedure
- Use upstream provided desktop file.
* Wed Oct 24 2012 p.drouand@gmail.com
- Fix build
* Mon Jun 25 2012 badshah400@gmail.com
- Update to version 2.5.1:
  + Figure insertion: swap \label and \caption
  + Use GResource for icons and symbols
  + Code refactoring for the symbols (in the side panel)
  + Fixes and improvements of the compilation with CMake
  + Updated Brazilian Portuguese, Czech, Serbian and Latvian
    translations
- Changes from version 2.5.0:
  + Port to GTK+ 3
  + Migrate from libunique to GtkApplication
  + Updated Spanish, Slovenian and French translations
* Thu Jun  7 2012 badshah400@gmail.com
- Update to version 2.4.1:
  + Figure insertion: swap \label and \caption
  + Updated French, Czech translations
  + Added Indonesian translation
- Changes from version 2.4.0:
  + Document compilation: set temporary location if file not saved
  + More documentation
  + Structure: bug fix for the display of simple lists
  + Build View: remove button "show critical errors"
  + Templates: code clean-up
  + More LaTeX commands for the completion
  + F12 shortcut to show/hide the side panel
  + TODO file removed (now in the wiki)
  + Updated Spanish, Slovenian, Serbian, French, German, Latvian,
    Norwegian bokmål and Czech translations
- Changes from version 2.3.1:
  + More completion data
  + Support drag and drop of a list of files
  + Completion: code clean-up
  + Beamer environments: frame, block, columns, column
    (in the LaTeX menu and in the edit toolbar)
  + Fix bug for structure actions 'delete' and 'cut'
  + Add Simplified Chinese, Norwegian bokmål translations
  + Updated Spanish translation
- Use upstream tarball (.tar.xz) for source.
* Fri Dec 16 2011 badshah400@gmail.com
- Prepare for submission to factory:
  + Remove sources for version 2.1.1
  + Package no longer builds for openSUSE < 12.1
  + Remove 0%%{?suse_version} > 1140 conditionals since package no
    longer builds for these versions anyway.
* Mon Dec 12 2011 badshah400@gmail.com
- Update to version 2.3.0:
  + Spell checking with GtkSpell
  + Build Tools: add XeTeX -> PDF with Latexmk
  + Improve figure environment insertion
  + Templates: better icons
  + Added Esperanto translation
  + Updated Swedish, French and German translations
  + New CMake option: VALAC
  + Switch to Vala 0.14
- Too many updates since version 2.0.8 from previous build, see
  /usr/share/doc/packages/latexila/NEWS for the complete list.
- Fix build failures on openSUSE > 11.4
- Versions 2.2.0 and above introduce a build dependency on itstool
  which is not available for openSUSE <= 11.4; use version 2.1.1
  as the highest that can build with openSUSE 11.4 and older.
* Wed Jun 22 2011 malcolmlewis@opensuse.org
- Initial build
